==> wallaroo-2023.4.1-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/model/upload_from_registry.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.upload_from_registry_json_body import UploadFromRegistryJsonBody
from ...models.upload_from_registry_response_200 import \
    UploadFromRegistryResponse200
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: UploadFromRegistryJsonBody,

) -> Dict[str, Any]:
    url = "{}/v1/api/models/upload_from_registry".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[UploadFromRegistryResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = UploadFromRegistryResponse200.from_dict(response.json())



        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[UploadFromRegistryResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: UploadFromRegistryJsonBody,

) -> Response[UploadFromRegistryResponse200]:
    """ 
    Args:
        json_body (UploadFromRegistryJsonBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadFromRegistryResponse200]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Client,
    json_body: UploadFromRegistryJsonBody,

) -> Optional[UploadFromRegistryResponse200]:
    """ 
    Args:
        json_body (UploadFromRegistryJsonBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadFromRegistryResponse200
     """


    return sync_detailed(
        client=client,
json_body=json_body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    json_body: UploadFromRegistryJsonBody,

) -> Response[UploadFromRegistryResponse200]:
    """ 
    Args:
        json_body (UploadFromRegistryJsonBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadFromRegistryResponse200]
     """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Client,
    json_body: UploadFromRegistryJsonBody,

) -> Optional[UploadFromRegistryResponse200]:
    """ 
    Args:
        json_body (UploadFromRegistryJsonBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadFromRegistryResponse200
     """


    return (await asyncio_detailed(
        client=client,
json_body=json_body,

    )).parsed

==> wallaroo-2024.2.0b2-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/model/upload_from_registry.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.upload_from_registry_body import UploadFromRegistryBody
from ...models.upload_from_registry_response_200 import UploadFromRegistryResponse200
from ...types import Response


def _get_kwargs(
    *,
    body: UploadFromRegistryBody,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/v1/api/models/upload_from_registry",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[UploadFromRegistryResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = UploadFromRegistryResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[UploadFromRegistryResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: UploadFromRegistryBody,
) -> Response[UploadFromRegistryResponse200]:
    """
    Args:
        body (UploadFromRegistryBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadFromRegistryResponse200]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: UploadFromRegistryBody,
) -> Optional[UploadFromRegistryResponse200]:
    """
    Args:
        body (UploadFromRegistryBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadFromRegistryResponse200
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: UploadFromRegistryBody,
) -> Response[UploadFromRegistryResponse200]:
    """
    Args:
        body (UploadFromRegistryBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadFromRegistryResponse200]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: UploadFromRegistryBody,
) -> Optional[UploadFromRegistryResponse200]:
    """
    Args:
        body (UploadFromRegistryBody): Payload for the List Registries call.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadFromRegistryResponse200
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
